// javascript functions for all wiki pages
$('document').ready(function() {
    console.log('document ready')
    setTimeout(function() {
    $('.entrance').hide("slide", { direction: "up" }, 1800)
    }, 2000)
});

function imgHover(element, newSrc) {
    /* swaps one image for another upon hovering
       Parameters:
        - element = img element 
        - newSrc = string with url to new image
    */
    element.setAttribute('src', newSrc);
}

function imgUnhover(element, oldSrc) {
    /* swaps new image back to original upon un-hovering
       Parameters:
        - element = img element 
        - oldSrc = string with url to original image
    */
        element.setAttribute('src', oldSrc);
}

$.fn.isInViewport = function() {
    /* determines whether an element is in the user's viewport or not (returns boolean) 
        example usage: 
        if ($('#timeline').isInViewport()) { do whatever code } 
    */
    var elementTop = $(this).offset().top;
    var elementBottom = elementTop + $(this).outerHeight();

    var viewportTop = $(window).scrollTop();
    var viewportBottom = viewportTop + $(window).height();

    return elementBottom > viewportTop && elementTop < viewportBottom && $(this).css('display') != 'none';
};

$.fn.isAtBottomOfViewport = function() {
    /* determines whether an element is at the very bottom the user's viewport or not (returns boolean) 
        example usage: 
        if ($('#timeline').isAtBottomOfViewport()) { do whatever code } 
    */
    return ($(window).scrollTop() >= $(this).offset().top + $(this).outerHeight() - window.innerHeight)
};

function countTo(start, end, element, withPercent, intervalLength){
    /* displays a counter going from `start` to `end` (both ints) for `element` (str)
       If withPercent === true, will add a percent symbol at the end of the number
    */
       let step = end > start ? 1 : -1;
       const interval = intervalLength;
   
       if(start == end){
           document.querySelector(`#${element}`).textContent = withPercent ? start.toString() + '%' : start
           return;
       }
   
       let counter = setInterval(function(){
           start += step;
           document.querySelector(`#${element}`).textContent = withPercent ? start.toString() + '%' : start
           if(start == end){
               clearInterval(counter);
           }
       }, interval);
   }


/* HOME PAGE */

if (window.location.href.endsWith("mit/") || window.location.href.indexOf("index") > -1 || window.location.href == 'http://127.0.0.1:8080/'){
    const headerHeight = 2*document.querySelector('#home-header').clientHeight / window.outerHeight
    console.log(headerHeight)
    document.querySelector('#home-header-container').style.height = `${100*headerHeight}vh`
    document.querySelector('#home-header').style.fontSize = 'calc(2.5*(1.475rem + 2.7vw))'
    document.querySelector('#home-header').style.color = 'transparent'
    document.querySelector('#home-lead').style.color = '#fff'

    setTimeout(function() {
        document.querySelector('#home-header').style.transition = 'color 0.4s ease-in-out'
    }, 8000)


    window.addEventListener('resize', function(event){
        const headerHeight = 2 * (document.querySelector('#home-header').offsetHeight + document.querySelector('#home-lead').offsetHeight)
        console.log(headerHeight)
        document.querySelector('#home-header-container').style.height = `${headerHeight}px`
      });

    
    setTimeout(function() {
        // count up/down for statistics and set intervals to end at same time
        let countToPercentPatients = countTo(0, 80, 'percent_patients', true, 10)
        let countToPercentDeaths = countTo(0, 30, 'percent_deaths', true, 80/3)
        let countToNumTreatments = countTo(100, 0, 'num_treatments', false, 8)
        document.querySelector('#home-header-container').style.transitionDelay = '0s'; 
    }, 3600)
}


/* DESCRIPTION PAGE */

if (window.location.href.indexOf("description") > -1) {
    // on ready, hide the timeline
    $('document').ready(function() {
        $('#timeline').hide()
    });

    // when the user scrolls down to the therapy text, reveal the timeline
    $(window).on( "scroll", function() {
        console.log($('#therapy').isAtBottomOfViewport()) 
        if ($('#therapy').isAtBottomOfViewport()) {
            setTimeout(function() {
                $('#timeline').slideDown(4000);
            }, 600)
        }
    })
}

/* HUMAN PRACTICES PAGE */
if (window.location.href.indexOf("human-practices") > -1) {
    $('.hp-info').each(function() { // initially hide all the detailed info
        $(this).animate({
            height : 'toggle'
        })
    })
    $(".learn-more").each(function() { // same behavior for all learn-more blocks
        $(this).css('cursor', 'pointer')
        let name = $(this).attr('id') // e.g., 'wittrup-button'
        name = name.substring(0,name.indexOf('-')) // e.g. 'wittrup'
        $(this).on('click', function() {
                $(`#${name}-info`).animate({  // reveal info about our meeting with that person
                    height : 'toggle'
                })
            })
        })

    // Get the modal
    var modal = document.getElementById("dabomb-modal");

    // Get the image and insert it inside the modal - use its "alt" text as a caption
    var img = document.getElementById("dabomb-small");
    var modalImg = document.getElementById("dabomb-large");
    img.onclick = function(){
        modal.style.display = "block";
        modalImg.src = this.src;
    }

    // When the user clicks on the close symbol OR anywhere outside the poster, close the modal
    modal.onclick = function() {
        modal.style.display = 'none'
    }
}

/* CODON OPTIMIZATION TOOL PAGE */
if (window.location.href.indexOf('codon') > -1) {
    $('#final').css('cursor', 'pointer')
    $('#final').on('click', function() {
        const finalSeq = document.querySelector('#final').getAttribute('name')
        navigator.clipboard.writeText(finalSeq)
        document.querySelector('#copied').style.color = '#cb0060'
        setTimeout(() => {
            document.querySelector('#copied').style.transition = 'color 2s'
            document.querySelector('#copied').style.color = '#ffffff00'
        }, 100)
        document.querySelector('#copied').style.transition = 'color 0s'
    })
}

/* ALIGNMENT TOOL PAGE */
if (window.location.href.indexOf('align') > -1) {
    $('#align-button').on('click', function() {
        URL.revokeObjectURL(document.getElementById("download").href); // delete URL, no longer needed
    })
}

/* ENGINEERING PAGE */
if (window.location.href.indexOf('engineering') > -1) {
    $(".learn-more").each(function() { // same behavior for all learn-more blocks
        $(this).css('cursor', 'pointer')
        let name = $(this).attr('id') // e.g., 'initial-button'
        name = name.substring(0,name.indexOf('-')) // e.g. 'initial'
        $(this).on('click', function() {
                $(`#${name}-info`).animate({  // reveal info
                    height : 'toggle'
                })
            })
        })
}

/* EXPERIMENTS AND RESULTS PAGES */
if (window.location.href.indexOf('experiments') > -1 || window.location.href.indexOf('results') > -1) {
    $('div').each(function() { // initially hide all the detailed info
        if (this.id.indexOf('info') > -1) {
            $(this).animate({
                height : 'toggle'
            })
        }
    })

    $(".learn-more").each(function() { // same behavior for all learn-more blocks
        $(this).css('cursor', 'pointer')
        let name = $(this).attr('id') // e.g., 'initial-button'
        name = name.substring(0,name.indexOf('-')) // e.g. 'initial'
        $(this).on('click', function() {
                $(`#${name}-info`).animate({  // reveal info
                    height : 'toggle'
                })
            })
        })
}




